Analysis
========

This module provides tools for analyzing and visualizing benchmark results.

.. automodule:: attackbench.metrics.analysis
   :members:
   :undoc-members:
   :show-inheritance:

Optimality
----------

.. automodule:: attackbench.metrics.optimality
   :members:
   :undoc-members:
   :show-inheritance:

Global Optimality
-----------------

.. automodule:: attackbench.metrics.global_optimality
   :members:
   :undoc-members:
   :show-inheritance:

Curves
------

.. automodule:: attackbench.metrics.curves
   :members:
   :undoc-members:
   :show-inheritance:

Ensemble
--------

.. automodule:: attackbench.metrics.ensemble
   :members:
   :undoc-members:
   :show-inheritance:
